This directory holds sources for minified javascript files, for Debian
policy compliance reasons.

# interfaces/Glitter/templates/static/javascripts/date.min.js
date-en-US_1.0.0-rc3.js

# interfaces/Glitter/templates/static/javascripts/jquery-3.5.1.min.js
jquery-3.5.1.js

# interfaces/Glitter/templates/static/javascripts/jquery-ui.min.js
jquery-ui_1.12.1.js

# interfaces/Glitter/templates/static/javascripts/jquery.peity.min.js
jquery.peity_3.3.0.js

# interfaces/Glitter/templates/static/javascripts/knockout-3.5.1.min.js
knockout-3.5.1.js

# interfaces/Glitter/templates/static/javascripts/knockout-extensions.js
knockout.mapping_2.4.1.js

# interfaces/Glitter/templates/static/javascripts/moment-2.26.0.min.js
moment_2.26.0.js

# interfaces/Glitter/templates/static/javascripts/jquery.hotkeys.min.js
jquery.hotkeys.js
